| Title: | Improved Trimmed Weighted Hochberg Procedures and Sample Size Optimization |
|---|---|
| Description: | The improved trimmed weighted Hochberg procedure provides increased statistical power and relaxes the dependence assumptions for familywise error rate control compared to the original weighted Hochberg procedure. This package computes the boundaries required for implementing the proposed methodology and includes sample size optimization methods. See Gou, J., Chang, Y., Li, T., and Zhang, F.(2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report. |
| Authors: | Jiangtao Gou [aut, cre], Fengqing (Zoe) Zhang [aut], Yizhuo Chang [ctb], Tianqi Li [ctb] |
| Maintainer: | Jiangtao Gou <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.0 |
| Built: | 2026-05-16 05:00:59 UTC |
| Source: | https://github.com/cran/itrimhoch |
Find the difference between the error rate when k and rho are both given and the prespecified alpha level
find_k_given_rho_target_mvtnorm(k, rho, alpha, alphavec = c(alpha/2, alpha/2))find_k_given_rho_target_mvtnorm(k, rho, alpha, alphavec = c(alpha/2, alpha/2))
k |
a pre-specified constant in the improved trimmed weighted Hochberg procedure |
rho |
the correlation coefficient between two test statistics |
alpha |
the significance level |
alphavec |
a numeric vector of two values representing the weighted significance levels assigned to the two hypotheses |
the difference between the error rate when k is specified and rho is optimal and the prespecified alpha level
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the difference between the error rate when k is specified and rho is optimal and the prespecified alpha level
find_k_target_mvtnorm(k, alpha, alphavec = c(alpha/2, alpha/2))find_k_target_mvtnorm(k, alpha, alphavec = c(alpha/2, alpha/2))
k |
a pre-specified constant in the improved trimmed weighted Hochberg procedure |
alpha |
the significance level |
alphavec |
a numeric vector of two values representing the weighted significance levels assigned to the two hypotheses |
the difference between the error rate when k is specified and rho is optimal and the prespecified alpha level
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the partial derivative of the error rate with respect to the correlation coefficient rho when k and rho are given
find_rho_target_mvtnorm(rho, k, alpha, alphavec = c(alpha/2, alpha/2))find_rho_target_mvtnorm(rho, k, alpha, alphavec = c(alpha/2, alpha/2))
rho |
the correlation coefficient between two test statistics |
k |
a pre-specified constant in the improved trimmed weighted Hochberg procedure |
alpha |
the significance level |
alphavec |
a numeric vector of two values representing the weighted significance levels assigned to the two hypotheses |
the partial derivative of the error rate with respect to the correlation coefficient rho
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the difference between the achieved power and the desired power for rejecting H1 using the improved trimmed or truncated weighted Hochberg procedure
iHpTarget1(n, alpha1, alpha, k, beta1, deltavec, rho)iHpTarget1(n, alpha1, alpha, k, beta1, deltavec, rho)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
k |
a pre-specified constant in the improved trimmed weighted Hochberg procedure |
beta1 |
one minus the desired power for rejecting H1 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
the difference between the achieved power and the desired power for rejecting H1 using the improved trimmed or truncated weighted Hochberg procedure
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the difference between the achieved power and the desired power for rejecting H1 using the improved trimmed or truncated weighted Hochberg procedure with allowance for different data maturities
iHpTarget1m(n, alpha1, alpha, k, beta1, deltavec, rho, maturity)iHpTarget1m(n, alpha1, alpha, k, beta1, deltavec, rho, maturity)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
k |
a pre-specified constant in the improved trimmed weighted Hochberg procedure |
beta1 |
one minus the desired power for rejecting H1 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
maturity |
a numeric vector of two values representing the data maturities for the two hypotheses |
the difference between the achieved power and the desired power for rejecting H1
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the difference between the achieved power and the desired power for rejecting H2 using the improved trimmed or truncated weighted Hochberg procedure
iHpTarget2(n, alpha1, alpha, k, beta2, deltavec, rho)iHpTarget2(n, alpha1, alpha, k, beta2, deltavec, rho)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
k |
a pre-specified constant in the improved trimmed weighted Hochberg procedure |
beta2 |
one minus the desired power for rejecting H2 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
the difference between the achieved power and the desired power for rejecting H2 using the improved trimmed or truncated weighted Hochberg procedure
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the difference between the achieved power and the desired power for rejecting H2 using the improved trimmed or truncated weighted Hochberg procedure with allowance for different data maturities
iHpTarget2m(n, alpha1, alpha, k, beta2, deltavec, rho, maturity)iHpTarget2m(n, alpha1, alpha, k, beta2, deltavec, rho, maturity)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
k |
a pre-specified constant in the improved trimmed weighted Hochberg procedure |
beta2 |
one minus the desired power for rejecting H2 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
maturity |
a numeric vector of two values representing the data maturities for the two hypotheses |
the difference between the achieved power and the desired power for rejecting H2
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Calculate the x-coordinates of a function where zero crossings occur
interpolate_zero(values, x = NULL)interpolate_zero(values, x = NULL)
values |
a numeric vector representing the function's output at specific points |
x |
Aa vector of x-coordinates corresponding to the values. If not provided, it defaults to 1:length(values) |
the x-coordinates where zero crossings occur. If no crossings are found, it returns NA
Power for rejecting H1 using various types of the Hochberg Procedure
itwcHochPower(n, alpha1, alpha, deltavec, rho, proctype = "i", k = 0)itwcHochPower(n, alpha1, alpha, deltavec, rho, proctype = "i", k = 0)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
proctype |
the improved trimmed weighted Hochberg procedure is denoted by |
k |
a pre-specified constant in the improved trimmed weighted Hochberg procedure |
the power for rejecting H1 is denoted by pwr1, the power for rejecting H2 is denoted by pwr2, and the power for rejecting both H1 and H2 is denoted by pwr12
Jiangtao Gou
Fengqing Zhang
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
itwcHochPower(n = 100, alpha1 = 0.0125, alpha = 0.025, deltavec = c(0.2, 0.25), rho = 0.2, proctype = "i", k = 0) itwcHochPower(n = 100, alpha1 = 0.0125, alpha = 0.025, deltavec = c(0, 0), rho = 0, proctype = "w", k = 0)itwcHochPower(n = 100, alpha1 = 0.0125, alpha = 0.025, deltavec = c(0.2, 0.25), rho = 0.2, proctype = "i", k = 0) itwcHochPower(n = 100, alpha1 = 0.0125, alpha = 0.025, deltavec = c(0, 0), rho = 0, proctype = "w", k = 0)
The two-step algorithm to calculate the best k value for the improved trimmed Hochberg method to ensure that the maximum type I error rate reaches alpha exactly when rho is arbitrary
optk(alpha, alphavec = c(alpha/2, alpha/2))optk(alpha, alphavec = c(alpha/2, alpha/2))
alpha |
the significance level |
alphavec |
a numeric vector of two values representing the weighted significance levels assigned to the two hypotheses |
the best k value k_opt and the rho value that makes the type I error rate reaches the maximum value rho_opt
Jiangtao Gou
Fengqing Zhang
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
optk(alpha = 0.025)optk(alpha = 0.025)
Calculate the rho value that reaches the maximum type I error rate in the improved trimmed Hochberg method when k value is given
optrho(k, alpha, alphavec = c(alpha/2, alpha/2))optrho(k, alpha, alphavec = c(alpha/2, alpha/2))
k |
a pre-specified constant in the improved trimmed weighted Hochberg procedure |
alpha |
the significance level |
alphavec |
a numeric vector of two values representing the weighted significance levels assigned to the two hypotheses |
the rho value that makes the type I error rate reaches the maximum value rho_opt and the type I error rate errorrate
Jiangtao Gou
Fengqing Zhang
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
optrho(k = 2/3, alpha = 0.025)optrho(k = 2/3, alpha = 0.025)
Compute the optimal sample size for the improved trimmed weighted Hochberg procedure
optsamplesize_iHp( alpha, k, betavec, deltavec, rho, ninterval = c(2, 2000), alphalist = seq(from = 0, to = alpha, by = 0.005) )optsamplesize_iHp( alpha, k, betavec, deltavec, rho, ninterval = c(2, 2000), alphalist = seq(from = 0, to = alpha, by = 0.005) )
alpha |
the significance level |
k |
a pre-specified constant in the improved trimmed weighted Hochberg procedure |
betavec |
a numeric vector of two values, including one minus the desired power for rejecting H1 and one minus the desired power for rejecting H2 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
ninterval |
a vector containing the end-points of the interval to be searched for optimal sample size |
alphalist |
a vector of discrete alpha values |
the overall optimal sample size for the improved trimmed weighted Hochberg procedure
Jiangtao Gou
Fengqing Zhang
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
rrr <- 2 # Allocation ratio alpha <- 0.025 k <- 2/3 ninterval <- c(2, 1000) betavec <- c(0.05, 0.15) rho <- 0.3 psivec <- c(0.67, 0.73) thetavec <- log(psivec) deltavec <- (-thetavec)*sqrt(rrr)/(1+rrr) result <- optsamplesize_iHp(alpha = alpha, k = k, betavec = betavec, deltavec = deltavec, rho = rho, ninterval = ninterval) result$noptrrr <- 2 # Allocation ratio alpha <- 0.025 k <- 2/3 ninterval <- c(2, 1000) betavec <- c(0.05, 0.15) rho <- 0.3 psivec <- c(0.67, 0.73) thetavec <- log(psivec) deltavec <- (-thetavec)*sqrt(rrr)/(1+rrr) result <- optsamplesize_iHp(alpha = alpha, k = k, betavec = betavec, deltavec = deltavec, rho = rho, ninterval = ninterval) result$nopt
Compute the optimal sample size for the improved trimmed weighted Hochberg procedure with allowance for different data maturities
optsamplesize_iHpm( alpha, k, betavec, deltavec, rho, maturity, ninterval = c(2, 2000), alphalist = seq(from = 0, to = alpha, by = 0.005) )optsamplesize_iHpm( alpha, k, betavec, deltavec, rho, maturity, ninterval = c(2, 2000), alphalist = seq(from = 0, to = alpha, by = 0.005) )
alpha |
the significance level |
k |
a pre-specified constant in the improved trimmed weighted Hochberg procedure |
betavec |
a numeric vector of two values, including one minus the desired power for rejecting H1 and one minus the desired power for rejecting H2 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
maturity |
a numeric vector of two values representing the data maturities for the two hypotheses |
ninterval |
a vector containing the end-points of the interval to be searched for optimal sample size |
alphalist |
a vector of discrete alpha values |
the overall optimal sample size for the improved trimmed weighted Hochberg procedure with allowance for different data maturities
Jiangtao Gou
Fengqing Zhang
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
rrr <- 2 alpha <- 0.025 k <- 0.6761 ninterval <- c(2, 1000) betavec <- c(0.10, 0.10) rho <- 0.4 maturity <- c(0.65, 0.70) psivec <- c(0.67, 0.73) thetavec <- log(psivec) deltavec <- (-thetavec)*sqrt(rrr)/(1+rrr) result <- optsamplesize_iHpm(alpha = alpha, k = k, betavec = betavec, deltavec = deltavec, rho = rho, maturity = maturity, ninterval = ninterval) result$noptrrr <- 2 alpha <- 0.025 k <- 0.6761 ninterval <- c(2, 1000) betavec <- c(0.10, 0.10) rho <- 0.4 maturity <- c(0.65, 0.70) psivec <- c(0.67, 0.73) thetavec <- log(psivec) deltavec <- (-thetavec)*sqrt(rrr)/(1+rrr) result <- optsamplesize_iHpm(alpha = alpha, k = k, betavec = betavec, deltavec = deltavec, rho = rho, maturity = maturity, ninterval = ninterval) result$nopt
Compute the optimal sample size for the weighted trimmed or truncated Hochberg procedure
optsamplesize_tHp( alpha, betavec, deltavec, rho, ninterval = c(2, 2000), alphalist = seq(from = 0, to = alpha, by = 0.005) )optsamplesize_tHp( alpha, betavec, deltavec, rho, ninterval = c(2, 2000), alphalist = seq(from = 0, to = alpha, by = 0.005) )
alpha |
the significance level |
betavec |
a numeric vector of two values, including one minus the desired power for rejecting H1 and one minus the desired power for rejecting H2 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
ninterval |
a vector containing the end-points of the interval to be searched for optimal sample size |
alphalist |
a vector of discrete alpha values |
the overall optimal sample size for the weighted trimmed or truncated Hochberg procedure
Jiangtao Gou
Fengqing Zhang
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
psivec <- c(0.76, 0.72) thetavec <- log(psivec) deltavec <- (-thetavec)/2 result <- optsamplesize_tHp(alpha = 0.05, betavec = c(0.20, 0.10), deltavec = deltavec , rho = -0.1) result$noptpsivec <- c(0.76, 0.72) thetavec <- log(psivec) deltavec <- (-thetavec)/2 result <- optsamplesize_tHp(alpha = 0.05, betavec = c(0.20, 0.10), deltavec = deltavec , rho = -0.1) result$nopt
Compute the optimal sample size for the weighted Holm procedure with allowance for different data maturities
optsamplesize_wHolmpm( alpha, betavec, deltavec, rho, maturity, ninterval = c(2, 2000), alphalist = seq(from = 0, to = alpha, by = 0.005) )optsamplesize_wHolmpm( alpha, betavec, deltavec, rho, maturity, ninterval = c(2, 2000), alphalist = seq(from = 0, to = alpha, by = 0.005) )
alpha |
the significance level |
betavec |
a numeric vector of two values, including one minus the desired power for rejecting H1 and one minus the desired power for rejecting H2 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
maturity |
a numeric vector of two values representing the data maturities for the two hypotheses |
ninterval |
a vector containing the end-points of the interval to be searched for optimal sample size |
alphalist |
a vector of discrete alpha values |
the overall optimal sample size for the weighted Holm procedure with allowance for different data maturities
Jiangtao Gou
Fengqing Zhang
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
rrr <- 2 alpha <- 0.025 k <- 0.6761 ninterval <- c(2, 1000) betavec <- c(0.05, 0.15) rho <- 0.4 maturity <- c(0.65, 0.70) psivec <- c(0.67, 0.73) thetavec <- log(psivec) deltavec <- (-thetavec)*sqrt(rrr)/(1+rrr) result <- optsamplesize_wHolmpm(alpha = alpha, betavec = betavec, deltavec = deltavec , rho = rho, maturity = maturity, ninterval = ninterval) result$noptrrr <- 2 alpha <- 0.025 k <- 0.6761 ninterval <- c(2, 1000) betavec <- c(0.05, 0.15) rho <- 0.4 maturity <- c(0.65, 0.70) psivec <- c(0.67, 0.73) thetavec <- log(psivec) deltavec <- (-thetavec)*sqrt(rrr)/(1+rrr) result <- optsamplesize_wHolmpm(alpha = alpha, betavec = betavec, deltavec = deltavec , rho = rho, maturity = maturity, ninterval = ninterval) result$nopt
Compute the optimal sample size for the weighted Hochberg procedure
optsamplesize_wHp( alpha, betavec, deltavec, rho, ninterval = c(2, 2000), alphalist = seq(from = 0, to = alpha, by = 0.005) )optsamplesize_wHp( alpha, betavec, deltavec, rho, ninterval = c(2, 2000), alphalist = seq(from = 0, to = alpha, by = 0.005) )
alpha |
the significance level |
betavec |
a numeric vector of two values, including one minus the desired power for rejecting H1 and one minus the desired power for rejecting H2 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
ninterval |
a vector containing the end-points of the interval to be searched for optimal sample size |
alphalist |
a vector of discrete alpha values |
the overall optimal sample size for the weighted Hochberg procedure
Jiangtao Gou
Fengqing Zhang
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
psivec <- c(0.76, 0.72) thetavec <- log(psivec) deltavec <- (-thetavec)/2 result <- optsamplesize_wHp(alpha = 0.05, betavec = c(0.20, 0.10), deltavec = deltavec , rho = -0.1) result$noptpsivec <- c(0.76, 0.72) thetavec <- log(psivec) deltavec <- (-thetavec)/2 result <- optsamplesize_wHp(alpha = 0.05, betavec = c(0.20, 0.10), deltavec = deltavec , rho = -0.1) result$nopt
Find the difference between the achieved power and the desired power for rejecting H1 using the weighted trimmed or truncated Hochberg procedure
tHpTarget1(n, alpha1, alpha, beta1, deltavec, rho)tHpTarget1(n, alpha1, alpha, beta1, deltavec, rho)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
beta1 |
one minus the desired power for rejecting H1 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
the difference between the achieved power and the desired power for rejecting H1 using the weighted trimmed or truncated Hochberg procedure
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the difference between the achieved power and the desired power for rejecting H2 using the weighted trimmed or truncated Hochberg procedure
tHpTarget2(n, alpha1, alpha, beta2, deltavec, rho)tHpTarget2(n, alpha1, alpha, beta2, deltavec, rho)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
beta2 |
one minus the desired power for rejecting H2 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
the difference between the achieved power and the desired power for rejecting H2 using the weighted trimmed or truncated Hochberg procedure
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Calculate the type I error rate of the weighted Simes test
typeIerror_Simes_mvtnorm( rho, adjFct = 0, alpha, alphavec = c(alpha/2, alpha/2) )typeIerror_Simes_mvtnorm( rho, adjFct = 0, alpha, alphavec = c(alpha/2, alpha/2) )
rho |
the correlation coefficient between two test statistics |
adjFct |
a pre-specified constant in the improved weighted Hochberg procedure, called the adjustment factor or k value |
alpha |
the significance level |
alphavec |
a numeric vector of two values representing the weighted significance levels assigned to the two hypotheses |
the type I error rate
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
typeIerror_trimSimes_mvtnorm(rho = 0, adjFct = 0, alpha = 0.05)typeIerror_trimSimes_mvtnorm(rho = 0, adjFct = 0, alpha = 0.05)
Calculate the type I error rate of the trimmed weighted Simes test
typeIerror_trimSimes_mvtnorm( rho, adjFct, alpha, alphavec = c(alpha/2, alpha/2) )typeIerror_trimSimes_mvtnorm( rho, adjFct, alpha, alphavec = c(alpha/2, alpha/2) )
rho |
the correlation coefficient between two test statistics |
adjFct |
a pre-specified constant in the improved trimmed weighted Hochberg procedure, called the adjustment factor or k value |
alpha |
the significance level |
alphavec |
a numeric vector of two values representing the weighted significance levels assigned to the two hypotheses |
the type I error rate
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
typeIerror_trimSimes_mvtnorm(rho = 0, adjFct = 0, alpha = 0.05)typeIerror_trimSimes_mvtnorm(rho = 0, adjFct = 0, alpha = 0.05)
Find the difference between the achieved power and the desired power for rejecting H1 using the weighted Holm procedure
wHolmTarget1(n, alpha1, alpha, beta1, deltavec, rho)wHolmTarget1(n, alpha1, alpha, beta1, deltavec, rho)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
beta1 |
one minus the desired power for rejecting H1 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
the difference between the achieved power and the desired power for rejecting H1
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the difference between the achieved power and the desired power for rejecting H1 using the weighted Holm procedure with allowance for different data maturities
wHolmTarget1m(n, alpha1, alpha, beta1, deltavec, rho, maturity)wHolmTarget1m(n, alpha1, alpha, beta1, deltavec, rho, maturity)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
beta1 |
one minus the desired power for rejecting H1 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
maturity |
a numeric vector of two values representing the data maturities for the two hypotheses |
the difference between the achieved power and the desired power for rejecting H1
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the difference between the achieved power and the desired power for rejecting H2 using the weighted Holm procedure
wHolmTarget2(n, alpha1, alpha, beta2, deltavec, rho)wHolmTarget2(n, alpha1, alpha, beta2, deltavec, rho)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
beta2 |
one minus the desired power for rejecting H2 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
the difference between the achieved power and the desired power for rejecting H2
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the difference between the achieved power and the desired power for rejecting H2 using the weighted Holm procedure with allowance for different data maturities
wHolmTarget2m(n, alpha1, alpha, beta2, deltavec, rho, maturity)wHolmTarget2m(n, alpha1, alpha, beta2, deltavec, rho, maturity)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
beta2 |
one minus the desired power for rejecting H2 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
maturity |
a numeric vector of two values representing the data maturities for the two hypotheses |
the difference between the achieved power and the desired power for rejecting H2
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the difference between the achieved power and the desired power for rejecting H1 using the weighted Hochberg procedure
wHpTarget1(n, alpha1, alpha, beta1, deltavec, rho)wHpTarget1(n, alpha1, alpha, beta1, deltavec, rho)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
beta1 |
one minus the desired power for rejecting H1 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
the difference between the achieved power and the desired power for rejecting H1 using the weighted Hochberg procedure
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.
Find the difference between the achieved power and the desired power for rejecting H2 using the weighted Hochberg procedure
wHpTarget2(n, alpha1, alpha, beta2, deltavec, rho)wHpTarget2(n, alpha1, alpha, beta2, deltavec, rho)
n |
the sample size |
alpha1 |
the weighted significance levels assigned to H1 |
alpha |
the significance level |
beta2 |
one minus the desired power for rejecting H2 |
deltavec |
a numeric vector of two values representing the effect sizes for the two hypotheses |
rho |
the correlation coefficient between two test statistics |
the difference between the achieved power and the desired power for rejecting H2 using the weighted Hochberg procedure
Jiangtao Gou
Gou, J., Chang, Y., Li, T., and Zhang, F. (2025). Improved trimmed weighted Hochberg procedures with two endpoints and sample size optimization. Technical Report.